pub enum Clock {
Auto,
Async(Prescaler),
Sync(SyncDiv),
}Expand description
ADC clock selection.
Only the modes of this chip’s ADCs exist; ADCs without a prescaler take their clock from the RCC as is.
Variants
Auto
Use the ADC kernel clock selected in the RCC, with the smallest prescaler that keeps the ADC clock within the limit of the chip.
Async(Prescaler)
Use the ADC kernel clock selected in the RCC, divided by the given prescaler.
Sync(SyncDiv)
Use the ADC bus clock (synchronous mode), divided by the given divider.