embassy-stm32

Crates

git

Versions

stm32c011d6

Flavors

Config

Struct Config 

#[non_exhaustive]
pub struct Config { pub resolution: Option<Resolution>, pub averaging: Option<OversamplingRatio>, pub oversampling: Option<Oversampling>, pub clock: Clock, }
ADC configuration.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
resolution: Option<Resolution>

Conversion resolution. None keeps the hardware default, which is the highest resolution of the ADC.

averaging: Option<OversamplingRatio>

Hardware averaging: accumulate this many samples per conversion and scale the sum back to the configured resolution.

oversampling: Option<Oversampling>

Raw oversampler control; takes precedence over averaging.

clock: Clock

ADC clock selection.